body {
    font-family: sans-serif;
}

h1 {
    background: #0a1b25;
    color: white;
    padding: 10px;
    text-align: center;
}

h2 {
    color: #429fd8;
    background: #0a1b25;
    padding: 10px;
}

thead {
    background: #0a1b25;
    color: white;
}

th, td {
    padding: 5px 15px 5px 15px;
    margin: 0;
    font-weight: normal;
}

table {
    background: #429fd8;
    color: white;
    border-collapse: true;
    border-spacing: 0;
}

.axis path {
    fill: none;
    stroke: black;
}

.axis line {
    strock: black;
}

.bubble-chart .bubble,
.bar-chart .bar {
    fill: #14749b;
}

.bubble-chart .bubble:hover,
.bar-chart .bar:hover  {
    fill: #429fd8;
}

.bubble-chart .bubble.selected,
.bar-chart .bar.selected {
    fill: #0b334c;
}

.bubble-chart .bubble.error,
.bar-chart .bar.error {
    fill: red;
}

.bubble-chart text,
.bar-chart .graph text {
    font-family: sans-serif;
}

.bubble-chart .graph text,
.bar-chart .graph text {
    fill: white;
}

.bar-chart .bar {
    rx: 5px;
    ry: 5px;
}

.line-chart .line {
    stroke-width: 1px;
    stroke: #14749b;
    fill: none;
}

.line-chart .line:hover {
    stroke-width: 3px;
    stroke: #429fd8;
}

div.summary {
    width: 600px;
    display: inline-block;
}

div.summary > svg {
    width: 100%;
    height: 600px;
}

div.detail {
    width: 600px;
    display: inline-block;
}

div.detail > svg {
    width: 100%;
    height: 600px;
}

.header {
    margin-left: 150px;
    border-radius: 3px;
    display: inline-block;
    background: #0b334c;
    color: white;
}

.header > button {
    margin: 2px;
    padding: 5px;
    background-color:  #14749b;
    border-radius: 2px;
    border: none;
    color: white;
}

.header > button:hover {
    background-color:  #429fd8;
}

.header > select {
    -webkit-appearance: none; /*Removes default chrome and safari style*/
       -moz-appearance: none; /*Removes default style Firefox*/
        -ms-appearance: none; /*Removes default style MS IE/Edge*/
         -o-appearance: none; /*Removes default style Opera*/
            appearance: none; /*Removes default style*/
    /*background-color: inherit;*/ /* Doesn't work on IE */
    background-color: #0b334c;
    border: none;   /*Removes border*/
    color: inherit;
    font-family: inherit;
    font-size: inherit;
    font-weight: inherit;
    overflow: hidden;
    text-align: center;
    width: 220px;
}

.header > select::-ms-expand {
    display: none;
}

.error {
    color: red;
}